@@ -22,22 +22,33 @@ import PaginatedList
 import Repository
 import Legacy
 import GithubObject
+import HookDescription
+
 
 DEFAULT_BASE_URL = "https://api.github.com"
 DEFAULT_TIMEOUT = 10
 
-class Github( object ):
-    def __init__( self, login_or_token = None, password = None, base_url = DEFAULT_BASE_URL, timeout = DEFAULT_TIMEOUT):
-        self.__requester = Requester( login_or_token, password, base_url, timeout )
+
+class Github(object):
+    def __init__(self, login_or_token=None, password=None, base_url=DEFAULT_BASE_URL, timeout=DEFAULT_TIMEOUT):
+        self.__requester = Requester(login_or_token, password, base_url, timeout)
 
     @property
-    def rate_limiting( self ):
+    def FIX_REPO_GET_GIT_REF(self):
+        return self.__requester.FIX_REPO_GET_GIT_REF
+
+    @FIX_REPO_GET_GIT_REF.setter
+    def FIX_REPO_GET_GIT_REF(self, value):
+        self.__requester.FIX_REPO_GET_GIT_REF = value
+
+    @property
+    def rate_limiting(self):
         return self.__requester.rate_limiting
 
-    def get_user( self, login = GithubObject.NotSet ):
-        assert login is GithubObject.NotSet or isinstance( login, ( str, unicode ) ), login
+    def get_user(self, login=GithubObject.NotSet):
+        assert login is GithubObject.NotSet or isinstance(login, (str, unicode)), login
         if login is GithubObject.NotSet:
-            return AuthenticatedUser.AuthenticatedUser( self.__requester, { "url": "/user" }, completed = False )
+            return AuthenticatedUser.AuthenticatedUser(self.__requester, {"url": "/user"}, completed=False)
         else:
             headers, data = self.__requester.requestAndCheck(
                 "GET",
@@ -45,43 +56,42 @@ class Github( object ):
                 None,
                 None
             )
-            return NamedUser.NamedUser( self.__requester, data, completed = True )
+            return NamedUser.NamedUser(self.__requester, data, completed=True)
 
-    def get_organization( self, login ):
-        assert isinstance( login, ( str, unicode ) ), login
+    def get_organization(self, login):
+        assert isinstance(login, (str, unicode)), login
         headers, data = self.__requester.requestAndCheck(
             "GET",
             "/orgs/" + login,
             None,
             None
         )
-        return Organization.Organization( self.__requester, data, completed = True )
+        return Organization.Organization(self.__requester, data, completed=True)
 
-    def get_gist( self, id ):
-        assert isinstance( id, ( str, unicode ) ), id
+    def get_gist(self, id):
+        assert isinstance(id, (str, unicode)), id
         headers, data = self.__requester.requestAndCheck(
             "GET",
             "/gists/" + id,
             None,
             None
         )
-        return Gist.Gist( self.__requester, data, completed = True )
+        return Gist.Gist(self.__requester, data, completed=True)
 
-    def get_gists( self ):
-        headers, data = self.__requester.requestAndCheck( "GET", "/gists/public", None, None )
+    def get_gists(self):
         return PaginatedList.PaginatedList(
             Gist.Gist,
             self.__requester,
-            headers,
-            data
+            "/gists/public",
+            None
         )
 
-    def legacy_search_repos( self, keyword, language = GithubObject.NotSet ):
-        assert isinstance( keyword, ( str, unicode ) ), keyword
-        assert language is GithubObject.NotSet or isinstance( language, ( str, unicode ) ), language
-        args = {} if language is GithubObject.NotSet else { "language": language }
+    def legacy_search_repos(self, keyword, language=GithubObject.NotSet):
+        assert isinstance(keyword, (str, unicode)), keyword
+        assert language is GithubObject.NotSet or isinstance(language, (str, unicode)), language
+        args = {} if language is GithubObject.NotSet else {"language": language}
         return Legacy.PaginatedList(
-            "/legacy/repos/search/" + urllib.quote( keyword ),
+            "/legacy/repos/search/" + urllib.quote(keyword),
             args,
             self.__requester,
             "repositories",
@@ -89,10 +99,10 @@ class Github( object ):
             Repository.Repository,
         )
 
-    def legacy_search_users( self, keyword ):
-        assert isinstance( keyword, ( str, unicode ) ), keyword
+    def legacy_search_users(self, keyword):
+        assert isinstance(keyword, (str, unicode)), keyword
         return Legacy.PaginatedList(
-            "/legacy/user/search/" + urllib.quote( keyword ),
+            "/legacy/user/search/" + urllib.quote(keyword),
             {},
             self.__requester,
             "users",
@@ -100,25 +110,25 @@ class Github( object ):
             NamedUser.NamedUser,
         )
 
-    def legacy_search_user_by_email( self, email ):
-        assert isinstance( email, ( str, unicode ) ), email
+    def legacy_search_user_by_email(self, email):
+        assert isinstance(email, (str, unicode)), email
         headers, data = self.__requester.requestAndCheck(
             "GET",
             "/legacy/user/email/" + email,
             None,
             None
         )
-        return NamedUser.NamedUser( self.__requester, Legacy.convertUser( data[ "user" ] ), completed = False )
+        return NamedUser.NamedUser(self.__requester, Legacy.convertUser(data["user"]), completed=False)
 
-    def render_markdown( self, text, context = GithubObject.NotSet ):
-        assert isinstance( text, ( str, unicode ) ), text
-        assert context is GithubObject.NotSet or isinstance( context, Repository.Repository ), context
+    def render_markdown(self, text, context=GithubObject.NotSet):
+        assert isinstance(text, (str, unicode)), text
+        assert context is GithubObject.NotSet or isinstance(context, Repository.Repository), context
         post_parameters = {
             "text": text
         }
         if context is not GithubObject.NotSet:
-            post_parameters[ "mode" ] = "gfm"
-            post_parameters[ "context" ] = context._identity
+            post_parameters["mode"] = "gfm"
+            post_parameters["context"] = context._identity
         status, headers, data = self.__requester.requestRaw(
             "POST",
             "/markdown",
@@ -126,3 +136,12 @@ class Github( object ):
             post_parameters
         )
         return data
+
+    def get_hooks(self):
+        headers, data = self.__requester.requestAndCheck(
+            "GET",
+            "/hooks",
+            None,
+            None
+        )
+        return [HookDescription.HookDescription(self.__requester, attributes, completed=True) for attributes in data]
